@@ -1,5 +1,9 @@
 
 
+import os
+from tendril.config import AUTH0_NAMESPACE
+os.environ['AUTH0_RULE_NAMESPACE'] = AUTH0_NAMESPACE
+
 from fastapi import Security
 from fastapi_auth0 import Auth0, Auth0User
 from tendril.config import AUTH0_DOMAIN
@@ -9,9 +13,11 @@ from tendril.authz import scopes
 from tendril.utils import log
 logger = log.get_logger(__name__, log.DEBUG)
 
+
 logger.info("Using auth0 parameters:\n"
-            "  - domain   {} \n"
-            "  - audience {} ".format(AUTH0_DOMAIN, AUTH0_AUDIENCE))
+            "  - domain    {} \n"
+            "  - audience  {} \n"
+            "  - namespace {} ".format(AUTH0_DOMAIN, AUTH0_AUDIENCE, AUTH0_NAMESPACE))
 
 auth = Auth0(domain=AUTH0_DOMAIN,
              api_audience=AUTH0_AUDIENCE,
